pub struct CommandRunner<T: ICommandInfo> { /* private fields */ }Expand description
Queue and execute commands across a pool of workers.
Implementations
Sourceimpl<T: ICommandInfo + 'static> CommandRunner<T>
impl<T: ICommandInfo + 'static> CommandRunner<T>
Sourcepub fn new(
mediator: Arc<CommandMediator<T>>,
registry: Arc<CommandRegistry<T>>,
workers: Arc<WorkerPool<T>>,
) -> Self
pub fn new( mediator: Arc<CommandMediator<T>>, registry: Arc<CommandRegistry<T>>, workers: Arc<WorkerPool<T>>, ) -> Self
Create a new CommandRunner.
Sourcepub async fn start(&self, worker_count: usize)
pub async fn start(&self, worker_count: usize)
Start any number of workers.
Each worker will have a unique ID.
Status will be set to Running.
Sourcepub async fn queue_request<R: Executable + Into<T::Request> + Send + Sync + 'static>(
&self,
request: R,
) -> Result<(), Report<QueueError>>
pub async fn queue_request<R: Executable + Into<T::Request> + Send + Sync + 'static>( &self, request: R, ) -> Result<(), Report<QueueError>>
Queue a command as a request.
Sourcepub async fn get_commands(
&self,
) -> MutexGuard<'_, HashMap<T::Request, CommandStatus<T>>>
pub async fn get_commands( &self, ) -> MutexGuard<'_, HashMap<T::Request, CommandStatus<T>>>
Lock and return the current command status map.
The MutexGuard must be dropped promptly or Worker execution will block.