IRequest

Trait IRequest 

pub trait IRequest:
    Clone
    + Debug
    + DeserializeOwned
    + Eq
    + Hash
    + PartialEq
    + Send
    + Serialize
    + Sync { }
Marker trait for serializable command request enums.

  • Requests are keyed by their Hash in the CommandMediator.
  • If duplicate requests should be tracked independently, include a unique identifier.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors