CommandRunner

Struct CommandRunner 

pub struct CommandRunner<T: ICommandInfo> { /* private fields */ }
Queue and execute commands across a pool of workers.

Implementations

Source

impl<T: ICommandInfo + 'static> CommandRunner<T>

pub fn new( mediator: Arc<CommandMediator<T>>, registry: Arc<CommandRegistry<T>>, workers: Arc<WorkerPool<T>>, ) -> Self

Create a new CommandRunner.

pub async fn start(&self, worker_count: usize)

Start any number of workers.

Each worker will have a unique ID.

Status will be set to Running.

pub async fn drain(&self)

Stop workers after draining the queue.

pub async fn stop(&self)

Stop workers after their current work is complete

pub async fn queue_request<R: Executable + Into<T::Request> + Send + Sync + 'static>( &self, request: R, ) -> Result<(), Report<QueueError>>

Queue a command as a request.

pub async fn get_commands( &self, ) -> MutexGuard<'_, HashMap<T::Request, CommandStatus<T>>>

Lock and return the current command status map.

The MutexGuard must be dropped promptly or Worker execution will block.